@@ -4,36 +4,40 @@
 #'concentrations as a result of infusion dosing.
 #'
 #'@param chem.name Either the chemical name, CAS number, or the parameters must 
-#'be specified.
+#' be specified.
 #'@param chem.cas Either the chemical name, CAS number, or the parameters must 
-#'be specified.
+#' be specified.
+#' @param dtxsid EPA's 'DSSTox Structure ID (\url{http://comptox.epa.gov/dashboard})  
+#' the chemical must be identified by either CAS, name, or DTXSIDs
 #'@param parameters Chemical parameters from parameterize_pbtk (for model = 
-#''pbtk'), parameterize_3comp (for model = '3compartment), 
-#'parmeterize_1comp(for model = '1compartment') or parameterize_steadystate 
-#'(for model = '3compartmentss'), overrides chem.name and chem.cas.
+#' 'pbtk'), parameterize_3comp (for model = '3compartment), 
+#' parmeterize_1comp(for model = '1compartment') or parameterize_steadystate 
+#' (for model = '3compartmentss'), overrides chem.name and chem.cas.
 #'@param hourly.dose Hourly dose rate mg/kg BW/h.
 #'@param concentration Desired concentration type, 'blood' or default 'plasma'.
 #'@param suppress.messages Whether or not the output message is suppressed.
 #'@param recalc.blood2plasma Recalculates the ratio of the amount of chemical 
-#'in the blood to plasma using the input parameters. Use this if you have 
-#''altered hematocrit, Funbound.plasma, or Krbc2pu.
-#'@param bioactive.free.invivo If FALSE (default), then the total concentration is treated
-#' as bioactive in vivo. If TRUE, the the unbound (free) plasma concentration is treated as 
-#' bioactive in vivo. Only works with tissue = NULL in current implementation.
+#' in the blood to plasma using the input parameters. Use this if you have 
+#' altered hematocrit, Funbound.plasma, or Krbc2pu.
 #'@param tissue Desired tissue conentration (defaults to whole body 
 #'concentration.)
 #'@param restrictive.clearance If TRUE (default), then only the fraction of
 #' chemical not bound to protein is available for metabolism in the liver. If 
 #' FALSE, then all chemical in the liver is metabolized (faster metabolism due
 #' to rapid off-binding). 
+#'@param bioactive.free.invivo If FALSE (default), then the total concentration is treated
+#' as bioactive in vivo. If TRUE, the the unbound (free) plasma concentration is treated as 
+#' bioactive in vivo. Only works with tissue = NULL in current implementation.
 #'@param ... Additional parameters passed to parameterize function if 
-#'parameters is NULL.
+#' parameters is NULL.
 #'  
 #'@return Steady state concentration in uM units
 #'
 #'@author Robert Pearce and John Wambaugh
+#'@keywords 1compartment
 calc_analytic_css_1comp <- function(chem.name=NULL,
                                    chem.cas = NULL,
+                                   dtxsid = NULL,
                                    parameters=NULL,
                                    hourly.dose=1/24,
                                    concentration='plasma',
@@ -44,14 +48,31 @@ calc_analytic_css_1comp <- function(chem.name=NULL,
                                    bioactive.free.invivo = F,
                                    ...)
 {
-  if (is.null(chem.cas) & is.null(chem.name) & is.null(parameters))
-  {
-    stop('Parameters, chem.name, or chem.cas must be specified.')
-  }
-  if(is.null(parameters))
+
+  param.names.1comp <- model.list[["1compartment"]]$param.names
+  param.names.schmitt <- model.list[["schmitt"]]$param.names
+  
+# We need to describe the chemical to be simulated one way or another:
+  if (is.null(chem.cas) & 
+      is.null(chem.name) & 
+      is.null(dtxsid) &
+      is.null(parameters)) 
+    stop('parameters, chem.name, chem.cas, or dtxsid must be specified.')
+
+# Look up the chemical name/CAS, depending on what was provide:
+  if (is.null(parameters))
   {
+    out <- get_chem_id(
+            chem.cas=chem.cas,
+            chem.name=chem.name,
+            dtxsid=dtxsid)
+    chem.cas <- out$chem.cas
+    chem.name <- out$chem.name                                
+    dtxsid <- out$dtxsid  
+
     parameters <- parameterize_1comp(chem.cas=chem.cas,
                                     chem.name=chem.name,
+                                    dtxsid=dtxsid,
                                     suppress.messages=suppress.messages,
                                     restrictive.clearance=restrictive.clearance,
                                     ...)
@@ -72,7 +93,6 @@ calc_analytic_css_1comp <- function(chem.name=NULL,
       warning("Argument restrictive.clearance=FALSE ignored by model 1comp when parameters!=NULL.") 
     }
   }
-  parameters$Fgutabs <- parameters$Fgutabs * parameters$hepatic.bioavailability
   
   hourly.dose <- hourly.dose * parameters$Fgutabs
   Css <- hourly.dose / parameters$kelim / parameters$Vdist
