@@ -1,4 +1,4 @@
-#R CMD BATCH --no-timing --no-save other_tests.R other_tests.Rout
+#R CMD BATCH --no-timing --no-restore --no-save 3compss_test.R 3compss_test.Rout
 library(httk)
 options(warn=-1)
 
@@ -49,3 +49,5 @@ if (length(script.args) > 0)
 #    print(test.fig)
   }
 }
+
+quit("no")
\ No newline at end of file
